@@ -1,5 +1,4 @@
-import logging, os, zc.buildout
-import subprocess
+import os,sys, subprocess
 
 class Dependencies(object):
 
@@ -7,7 +6,7 @@ class Dependencies(object):
         self.name, self.options = name, options
         for executable, system_package in [
                 line.split(':') for line in options['bin'].split()]:
-            print('Testing: ' + executable)
+            sys.stdout.write('Checking ' + executable + ': ')
             try:
                 assert(not subprocess.call(['which', executable], stdout=subprocess.PIPE))
                 print('ok')
@@ -18,7 +17,7 @@ class Dependencies(object):
 
 
     def install(self):
-        pass
+        return []
 
     def update(self):
         pass
